
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Form.h>
#include <X11/Shell.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvRegion.h>
#include <X11/xv/xvGC.h>
#include <X11/xv/xvGraphic.h>
#include <X11/xv/xvBasicBitmap.h>
#include <X11/xv/xvWindow.h>
#include <stdio.h>
#include <string.h>

// ---------------------------------------------

xvWindow::xvWindow()
{
	BOpen=FALSE;
	alloc=FALSE;
}

// ---------------------------------------------

xvWindow::xvWindow(String name, String classname, xvCore &TopLevel)
{
	BOpen=FALSE;
	init(name, classname, TopLevel);
}

// ---------------------------------------------

xvWindow::~xvWindow()
{
	if (alloc) {
		this.Close();
		XtDestroyWidget(w);	
	}
}

// ---------------------------------------------

Widget xvWindow::GetParent()
{
	return(BParent);
}

// ---------------------------------------------

void xvWindow::init(String name, String classname, xvCore & TopLevel)
{

	BParent=XtVaAppCreateShell(name, classname, applicationShellWidgetClass, 
		XtDisplay(TopLevel.ID()), NULL);
	w=XtVaCreateManagedWidget(name, formWidgetClass, BParent,
		"resizable", TRUE, NULL);

	alloc=TRUE;
	iconmap.init(NULL, w);
}

// ---------------------------------------------

void xvWindow::Open()
{
	if (! BOpen) {
		XtRealizeWidget(BParent);
		xvGraphic::init(w);
		BOpen=TRUE;
	}
}

// --------------------------------------------

void xvWindow::Close()
{
	if (BOpen) {
		XtUnrealizeWidget(BParent);
		BOpen=FALSE;
	}
}

// ---------------------------------------------

void xvWindow::MovePointer(int x, int y)
{
	XWarpPointer(xvdisplay, None, xvwindow, 0, 0, 0, 0, x, y);
}

// --------------------------------------------

void xvWindow::SetWindowResource(String resname, XtArgVal res)
{
	XtVaSetValues(BParent, resname, res, NULL);
}

// --------------------------------------------

void xvWindow::GetWindowResource(String resname, XtArgVal *res)
{
	XtVaGetValues(BParent, resname, res, NULL);
}

// ---------------------------------------------

int xvWindow::LoadNewIcon(String name, int pixtype)
{
	int bmr=iconmap.ReadFile(name, pixtype);
	if (bmr==0) SetWindowResource(XtNiconPixmap, iconmap.GetPixmap());
	return(bmr);
}

// ---------------------------------------------

void xvWindow::FixBorder(Dimension width, Dimension height)
{
	SetWindowResource(XtNminWidth, (XtArgVal) width);
	SetWindowResource(XtNminHeight, (XtArgVal) height);
	SetWindowResource(XtNmaxWidth, (XtArgVal) width);
	SetWindowResource(XtNmaxHeight, (XtArgVal) height);
}

// ---------------------------------------------

void xvWindow::ReleaseBorder()
{
	SetWindowResource(XtNminWidth, XtUnspecifiedShellInt);
	SetWindowResource(XtNminHeight, XtUnspecifiedShellInt);
	SetWindowResource(XtNmaxWidth, XtUnspecifiedShellInt);
	SetWindowResource(XtNmaxHeight, XtUnspecifiedShellInt);
}

// ----------------------------------------------

void xvWindow::SetWindowLocation(Position x, Position y)
{
	char tempbuffer[180];
	
	sprintf(tempbuffer, "+%d+%d", x, y);
	SetWindowResource(XtNgeometry, (XtArgVal) tempbuffer);
}

// ----------------------------------------------
